import {
  ContentfulClientApi,
  createClient,
  Entry
} from 'contentful'

const space = process.env.NEXT_PUBLIC_CONTENTFUL_SPACE_ID
const accessToken = process.env.NEXT_PUBLIC_CONTENTFUL_ACCESS_TOKEN

const client: ContentfulClientApi = createClient({
  space,
  accessToken
})

export type ServiceType = {
  contactInformation: object
  description: object
  developer: object
  documentationURL: string
  name: string
  shortDescription: object
  sourcecodeURL?: string
  status: string
  slug: string
  logo: object
  tags?: any[]
  tosURL?: string
}

export type Tag = {
  fields: {
    name: string
  }
}

export async function fetchServices(): Promise<Entry<any>[]> {
  const services = await client.getEntries({
    content_type: 'service'
  })
  if (services.items) return services.items
  console.log('Error getting Entries for services.')
}

export async function fetchService(slug): Promise<Entry<any>> {
  const services = await client.getEntries({
    content_type: 'service'
  })
  return services.items.find(
    (service: Entry<ServiceType>) => service.fields.slug === slug
  )
}

export default { fetchServices, fetchService }
